@@ -1,7 +1,7 @@
 """
 Type annotations for fis service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/type_defs.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_fis/type_defs/)
 
 Usage::
 
